@@ -218,12 +218,30 @@ write_basis <- function(basis, basis_file) {
   
 #' Convert a basis object to an mrs_data object - where basis signals are spread
 #' across the dynamic dimension.
-#' @param basis Basis set object.
-#' @return An mrs_data object with basis signals spread across the dynamic dimension.
+#' @param basis basis set object.
+#' @param sum_elements return the sum of basis elements (logical)
+#' @param amp a vector of scaling factors to apply to each basis element.
+#' @return an mrs_data object with basis signals spread across the dynamic dimension.
 #' @export
-basis2mrs_data <- function(basis) {
-  mat2mrs_data(basis$data, fs = basis$fs, ft = basis$ft, ref = basis$ref, 
+basis2mrs_data <- function(basis, sum_elements = FALSE, amp = NULL) {
+  # scale basis elements
+  if (!is.null(amp)) {
+    if (dim(basis$data)[2] != length(amp)) {
+      stop(paste("Error, length of amp does not match the number of basis elements :", dim(basis$data)[2]))
+    }
+    for (n in 1:dim(basis$data)[2]) {
+      basis$data[,n] <- basis$data[,n] * amp[n]
+    }
+  }
+  
+  if (sum_elements) {
+    basis$data <- apply(basis$data, 1, sum)
+    vec2mrs_data(basis$data, fs = basis$fs, ft = basis$ft, ref = basis$ref, 
                fd = TRUE)
+  } else {
+    mat2mrs_data(basis$data, fs = basis$fs, ft = basis$ft, ref = basis$ref, 
+               fd = TRUE)
+  }
 }
 
 #' Convert an mrs_data object to basis object - where basis signals are spread
